@@ -197,7 +197,7 @@ SqlStatementResultTypeDef = TypedDict(
 StructValueTypeDef = TypedDict(
     "StructValueTypeDef",
     {
-        "attributes": List["ValueTypeDef"],
+        "attributes": List[Dict[str, Any]],
     },
     total=False,
 )
